@@ -1,36 +1,81 @@
-/* 
-desktop_entry.rs
-Rusified in 2021 Copyright Israel Dahl. All rights reserved.
-
-       /VVVV\
-     /V      V\
-   /V          V\
-  /      0 0     \
-  \|\|\</\/\>/|/|/
-       \_/\_/
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License version 2 as
-published by the Free Software Foundation.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-*/
+// desktop_entry.rs
+// Rusified in 2021 Copyright Israel Dahl. All rights reserved.
+// 
+//        /VVVV\
+//      /V      V\
+//    /V          V\
+//   /      0 0     \
+//   \|\|\</\/\>/|/|/
+//        \_/\_/
+// 
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License version 2 as
+// published by the Free Software Foundation.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 extern crate tini;
 use tini::Ini;
-
+use std::fmt;
 /// could just say use crate::utils::*
 use crate::utils::get_language;
 use crate::utils::to_bool;
 
+//use crate::categories::*;
+
+#[derive(Debug)]
+/// Registered OnlyShowIn Environments
+pub enum OnlyShowIn {
+	/// GNOME Desktop
+	GNOME,
+	/// GNOME Classic Desktop
+	GNOMEClassic,
+	/// GNOME Flashback Desktop
+	GNOMEFlashback,
+	/// KDE Desktop
+	KDE,
+	/// LXDE Desktop
+	LXDE,
+	/// LXQt Desktop
+	LXQt,
+	/// MATÉ Desktop
+	MATE,
+	/// Razor-qt Desktop
+	Razor,
+	/// ROX Desktop
+	ROX,
+	/// Trinity Desktop
+	TDE,
+	/// Unity Shell
+	Unity,
+	/// XFCE Desktop
+	XFCE,
+	/// EDE Desktop
+	EDE,
+	/// Cinnamon Desktop
+	Cinnamon,
+	/// Pantheon Desktop
+	Pantheon,
+	/// Legacy menu systems
+	Old,
+	/// This is for random people making whatever they want... `Unknown` is similar to Desktop Entry's `type`
+	Unknown,
+}
+impl fmt::Display for OnlyShowIn {
+	fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+	write!(f, "{:?}", self)
+	// or, alternatively:
+	// fmt::Debug::fmt(self, f)
+	}
+}
+
 /// This specification defines 3 types of desktop entries:
 /// * Application (type 1),
 /// * Link (type 2)
@@ -45,6 +90,13 @@ pub enum DesktopType {
 	/// Ignore 'Unknown' type in your program, it really just means it is anything other than the above known types
 	Unknown,
 }
+impl fmt::Display for DesktopType {
+	fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+	write!(f, "{:?}", self)
+	// or, alternatively:
+	// fmt::Debug::fmt(self, f)
+	}
+}
 
 /// This function converts a Option<String> to a DesktopType
 pub fn convert_xdg_type(xdg_type_option:Option<String>)->DesktopType {
@@ -184,10 +236,12 @@ impl DesktopEntry {
 		}
     }
     /// Creates a 'new' DesktopEntry from reading a file
+    /// note: xdgkit does not check the file extention, you *may* want to
+    /// This reads not only `.desktop` files but also `.directory`
     pub fn new(file_name:String)->Self where Self:Sized {
 		let test_ini = Ini::from_file(&file_name);
 		if test_ini.is_err() {
-			//TODO println!("ERROR!!!{}",file_name);
+			println!("ERROR!!! {:?} in {}",test_ini,file_name);
 			return Self::empty(DesktopType::Application)
 		}
 		let conf = test_ini.unwrap();
