@@ -1,28 +1,25 @@
-/* 
-utils.rs
-Rusified in 2021 Copyright Israel Dahl. All rights reserved.
-
-       /VVVV\
-     /V      V\
-   /V          V\
-  /      0 0     \
-  \|\|\</\/\>/|/|/
-       \_/\_/
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License version 2 as
-published by the Free Software Foundation.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-*/
+// utils.rs
+// Rusified in 2021 Copyright Israel Dahl. All rights reserved.
+// 
+//        /VVVV\
+//      /V      V\
+//    /V          V\
+//   /      0 0     \
+//   \|\|\</\/\>/|/|/
+//        \_/\_/
+// 
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License version 2 as
+// published by the Free Software Foundation.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 use std::env;
 /// This function changes an `Option<String>` into an `Option<bool>` via make_ascii_lowercase()
 pub fn to_bool(value:Option<String>)->Option<bool> {
